@@ -1,3 +1,13 @@
+#######################################################################
+# This file is part of PyBlosxom.
+#
+# Copyright (c) 2003, 2004, 2005, 2006 Wari Wahab
+# 
+# PyBlosxom is distributed under the MIT license.  See the file LICENSE
+# for distribution details.
+#
+# $Id: base.py 1043 2007-06-20 16:23:30Z willhelm $
+#######################################################################
 """
 The is the base renderer module.  If you were to dislike the blosxom
 renderer and wanted to build a renderer that used a different templating
@@ -7,7 +17,11 @@ functionality required by the other rendering system.
 For examples, look at the BlosxomRenderer and the Renderer in the debug
 module.
 """
+
+__revision__ = "$Revision: 1043 $"
+
 import sys
+import time
 
 class RendererBase:
     """
@@ -28,9 +42,13 @@ class RendererBase:
         @type stdoutput: file
         """
         self._request = request
-        self._header = {}
+
+        # this is a list of tuples of the form (key, value)
+        self._header = []
+
         self._out = stdoutput
         self._content = None
+        self._content_mtime = None
         self._needs_content_type = 1
         self.rendered = None
 
@@ -88,16 +106,15 @@ class RendererBase:
         @raises ValueError: This happens when the parameters are not correct
         """
         args = list(args)
-        if not len(args) % 2:
-            while args:
-                key = args.pop(0).strip()
-                if key.find(' ') != -1 or key.find(':') != -1:
-                    raise ValueError, 'There should be no spaces in header keys'
-                value = args.pop(0).strip()
-                self._header.update({key: value})
-        else:
+        if len(args) % 2 != 0:
             raise ValueError, 'Headers recieved are not in the correct form'
 
+        while args:
+            key = args.pop(0).strip()
+            if key.find(' ') != -1 or key.find(':') != -1:
+                raise ValueError, 'There should be no spaces in header keys'
+            value = args.pop(0).strip()
+            self._header.append( (key, value) )
 
     def setContent(self, content):
         """
@@ -108,6 +125,13 @@ class RendererBase:
             dict containing at least 'title' and 'body'
         """
         self._content = content
+        if isinstance(self._content, dict):
+            mtime = self._content.get("mtime", time.time())
+        elif isinstance(self._content, list):
+            mtime = self._content[0].get("mtime", time.time())
+        else:
+            mtime = time.time()
+        self._content_mtime = mtime
 
     
     def needsContentType(self, flag):
@@ -123,12 +147,13 @@ class RendererBase:
 
     def showHeaders(self):
         """
-        Updated the headers of the L{Response<Pyblosxom.pyblosxom.Response>} instance.
+        Updated the headers of the L{Response<Pyblosxom.pyblosxom.Response>} 
+        instance.
         This is just for backwards compatibility.
         """
         response = self._request.getResponse()
-        for k,v in self._header.items():
-            response.addHeader(k,v)
+        for k, v in self._header:
+            response.addHeader(k, v)
 
 
     def render(self, header = 1):
@@ -150,4 +175,7 @@ class RendererBase:
         self.rendered = 1
 
 class Renderer(RendererBase):
+    """
+    This is a null renderer.
+    """
     pass
